| Title: | Data Sets from "Forecasting with Exponential Smoothing" |
|---|---|
| Description: | Data sets from the book "Forecasting with exponential smoothing: the state space approach" by Hyndman, Koehler, Ord and Snyder (Springer, 2008). |
| Authors: | Rob Hyndman [aut, cre, cph] (ORCID: <https://orcid.org/0000-0002-2140-5352>), Justin Carmody [ctb] |
| Maintainer: | Rob Hyndman <[email protected]> |
| License: | GPL-3 |
| Version: | 2.3.0.9000 |
| Built: | 2026-05-17 07:22:49 UTC |
| Source: | https://github.com/robjhyndman/expsmooth |
Quarterly Australian GDP per capita, 1971:1 - 1998:1
ausgdpausgdp
time series
Hyndman, R.J., Koehler, A.B., Ord, J.K., and Snyder, R.D., (2008) Forecasting with exponential smoothing: the state space approach, Springer.
https://robjhyndman.com/expsmooth/
plot(ausgdp, main = "Australian GDP per capita", ylab = "dollars", xlab = "Year")plot(ausgdp, main = "Australian GDP per capita", ylab = "dollars", xlab = "Year")
Monthly US government 10-year bond yields (percent pa) from Jan 1994 to May 2004
bondsbonds
time series
Hyndman, R.J., Koehler, A.B., Ord, J.K., and Snyder, R.D., (2008) Forecasting with exponential smoothing: the state space approach, Springer.
https://robjhyndman.com/expsmooth/
plot(bonds, main = "US 10-year bonds yield", ylab = "Percentage per annum", xlab = "Year")plot(bonds, main = "US 10-year bonds yield", ylab = "Percentage per annum", xlab = "Year")
Monthly Canadian gas production, billions of cubic metres, January 1960 - February 2005
cangascangas
time series
Hyndman, R.J., Koehler, A.B., Ord, J.K., and Snyder, R.D., (2008) Forecasting with exponential smoothing: the state space approach, Springer.
https://robjhyndman.com/expsmooth/
plot(cangas, main = "Monthly Canadian gas production", ylab = "billion cubic metres", xlab = "Year")plot(cangas, main = "Monthly Canadian gas production", ylab = "billion cubic metres", xlab = "Year")
Monthly sales car parts. 2674 series. Jan 1998 - Mar 2002.
carpartscarparts
multiple time series
Hyndman, R.J., Koehler, A.B., Ord, J.K., and Snyder, R.D., (2008) Forecasting with exponential smoothing: the state space approach, Springer
https://robjhyndman.com/expsmooth/
plot(carparts[, 2001:2010], main = "Monthly car part sales", xlab = "Year")plot(carparts[, 2001:2010], main = "Monthly car part sales", xlab = "Year")
Monthly Dow Jones Index: Open, High, Low, Close. Jan 1990 - Mar 2007
djidji
multiple time series
Hyndman, R.J., Koehler, A.B., Ord, J.K., and Snyder, R.D., (2008) Forecasting with exponential smoothing: the state space approach, Springer.
https://robjhyndman.com/expsmooth/
plot(dji, plot.type = "single", main = "Dow Jones Index", xlab = "Year", ylab = "", col = 1:4) legend("bottomright", legend = colnames(dji), col = 1:4, lty = 1)plot(dji, plot.type = "single", main = "Dow Jones Index", xlab = "Year", ylab = "", col = 1:4) legend("bottomright", legend = colnames(dji), col = 1:4, lty = 1)
Closing values of the Dow Jones Index on the first day of each month,
October 1928 - Dec 2007. Two columns: close and pcreturn.
djiclosedjiclose
multiple time series
Hyndman, R.J., Koehler, A.B., Ord, J.K., and Snyder, R.D., (2008) Forecasting with exponential smoothing: the state space approach, Springer.
https://robjhyndman.com/expsmooth/
plot(djiclose, main = "Dow Jones Index", xlab = "Year")plot(djiclose, main = "Dow Jones Index", xlab = "Year")
"Domestic Revenue Enplanements (millions): 1996-2000. SOURCE: Department of Transportation, Bureau of Transportation Statistics, Air Carrier Traffic Statistic Monthly.
enplanementsenplanements
time series
Hyndman, R.J., Koehler, A.B., Ord, J.K., and Snyder, R.D., (2008) Forecasting with exponential smoothing: the state space approach, Springer
https://robjhyndman.com/expsmooth/
plot(enplanements, main = "US domestic enplanements", ylab = "millions", xlab = "Year")plot(enplanements, main = "US domestic enplanements", ylab = "millions", xlab = "Year")
Sales of a product for 62 weeks starting in early 2003.
fmsalesfmsales
time series
Hyndman, R.J., Koehler, A.B., Ord, J.K., and Snyder, R.D., (2008) Forecasting with exponential smoothing: the state space approach, Springer.
https://robjhyndman.com/expsmooth/
plot(fmsales, ylab = "FM sales (thousands)", xlab = "Week")plot(fmsales, ylab = "FM sales (thousands)", xlab = "Week")
Annual US new freight cars, 1947-1993. Freight cars, new (excl. rebuilt), new orders, equip. mfrers. Series N0193 from the M3 competition.
freightfreight
time series
Hyndman, R.J., Koehler, A.B., Ord, J.K., and Snyder, R.D., (2008) Forecasting with exponential smoothing: the state space approach, Springer. https://robjhyndman.com/expsmooth/
plot(freight, main = "New freight cars shipped in USA", xlab = "Year", ylab = "")plot(freight, main = "New freight cars shipped in USA", xlab = "Year", ylab = "")
Quarterly exports of a French company. (in thousands of francs) taken from Makridakis et al. (1998, p.162).
frexportfrexport
time series
Hyndman, R.J., Koehler, A.B., Ord, J.K., and Snyder, R.D., (2008) Forecasting with exponential smoothing: the state space approach, Springer.
https://robjhyndman.com/expsmooth/
plot(frexport, ylab = "thousands of francs", main = "Quarterly exports", xlab = "Year")plot(frexport, ylab = "thousands of francs", main = "Quarterly exports", xlab = "Year")
Monthly US retail gasoline price (the average price per gallon, in dollars) and the spot price of a barrel of West Texas Intermediate (WTI) oil in dollars as traded at Cushing, Oklahoma. Jan 1991 - Nov 2006.
gaspricegasprice
bivariate time series
Hyndman, R.J., Koehler, A.B., Ord, J.K., and Snyder, R.D., (2008) Forecasting with exponential smoothing: the state space approach, Springer.
https://robjhyndman.com/expsmooth/. These series were obtained from the US Energy Information Administration website https://www.eia.gov.
par(mar = c(5, 4, 2, 5)) plot(gasprice[, 1], xlab = "Year", ylab = "Average retail price per gallon (dollars)", main = "Gasoline and oil prices" ) par(new = TRUE) plot(gasprice[, 2], col = "blue", xaxt = "n", yaxt = "n", xlab = "", ylab = "") axis(4) mtext("Spot price per barrel (dollars)", side = 4, line = 3) legend("topleft", col = c("black", "blue"), lty = 1, legend = c("Ave retail price of gasoline", "Spot price of WTI oil") )par(mar = c(5, 4, 2, 5)) plot(gasprice[, 1], xlab = "Year", ylab = "Average retail price per gallon (dollars)", main = "Gasoline and oil prices" ) par(new = TRUE) plot(gasprice[, 2], col = "blue", xaxt = "n", yaxt = "n", xlab = "", ylab = "") axis(4) mtext("Spot price per barrel (dollars)", side = 4, line = 3) legend("topleft", col = c("black", "blue"), lty = 1, legend = c("Ave retail price of gasoline", "Spot price of WTI oil") )
Monthly patient count for products that are related to medical problems. There are 767 time series that had a mean count of at least 10 and no zeros.
hospitalhospital
multiple time series
Hyndman, R.J., Koehler, A.B., Ord, J.K., and Snyder, R.D., (2008) Forecasting with exponential smoothing: the state space approach, Springer
https://robjhyndman.com/expsmooth/
plot(hospital[, 1:10], main = "Monthly patient count", xlab = "Year")plot(hospital[, 1:10], main = "Monthly patient count", xlab = "Year")
Weekly sales of 314 costume jewelry items over the period week 5, 1998 to week 24, 2000.
jewelryjewelry
multiple time series
Hyndman, R.J., Koehler, A.B., Ord, J.K., and Snyder, R.D., (2008) Forecasting with exponential smoothing: the state space approach, Springer.
https://robjhyndman.com/expsmooth/
plot(jewelry[, 1:10], main = "Weekly sales of costume jewelry items", xlab = "Year")plot(jewelry[, 1:10], main = "Weekly sales of costume jewelry items", xlab = "Year")
Monthly copper prices. Copper, grade A, electrolytic wire bars/cathodes,LME,cash (pounds/ton) Source: UNCTAD (https://unctadstat.unctad.org/EN/).
mcoppermcopper
time series
Hyndman, R.J., Koehler, A.B., Ord, J.K., and Snyder, R.D., (2008) Forecasting with exponential smoothing: the state space approach, Springer
https://robjhyndman.com/expsmooth/
plot(mcopper, main = "Monthly copper price", ylab = "pounds per ton", xlab = "Year")plot(mcopper, main = "Monthly copper price", ylab = "pounds per ton", xlab = "Year")
Monthly sales for a product with shortage indicators. Contains sales (first column) and stockout indicator (second column).
msalesmsales
time series
Hyndman, R.J., Koehler, A.B., Ord, J.K., and Snyder, R.D., (2008) Forecasting with exponential smoothing: the state space approach, Springer
https://robjhyndman.com/expsmooth/
plot(msales[, 1], main = "Monthly sales of a product", ylab = "Sales", xlab = "Year") points(msales, pch = (msales[, "stockouts"] == 1) + 1) legend("bottomright", pch = 1:2, legend = c("Excess stock", "Stock shortage"))plot(msales[, 1], main = "Monthly sales of a product", ylab = "Sales", xlab = "Year") points(msales, pch = (msales[, "stockouts"] == 1) + 1) legend("bottomright", pch = 1:2, legend = c("Excess stock", "Stock shortage"))
Monthly sales of an automobile part.
partxpartx
time series
Hyndman, R.J., Koehler, A.B., Ord, J.K., and Snyder, R.D., (2008) Forecasting with exponential smoothing: the state space approach, Springer
https://robjhyndman.com/expsmooth/
plot(partx, main = "Monthly sales of an automobile part", ylab = "Sales", xlab = "Year")plot(partx, main = "Monthly sales of an automobile part", ylab = "Sales", xlab = "Year")
Quarterly UK passenger car production (thousands of cars). 1977:1-2005:1
ukcarsukcars
time series
Hyndman, R.J., Koehler, A.B., Ord, J.K., and Snyder, R.D., (2008) Forecasting with exponential smoothing: the state space approach, Springer
https://robjhyndman.com/expsmooth/
plot(ukcars, main = "UK passenger vehicle production", ylab = "Thousands of cars", xlab = "Year")plot(ukcars, main = "UK passenger vehicle production", ylab = "Thousands of cars", xlab = "Year")
100 monthly observations on the consumer confidence index (cci) and
seasonally adjusted civilian unemployment (unemp) in the US, covering
the period June 1997 – September 2005. The third column is an "terrorism"
indicator variable taking value 1 from September 2001.
unemp.cciunemp.cci
multiple time series
Hyndman, R.J., Koehler, A.B., Ord, J.K., and Snyder, R.D., (2008) Forecasting with exponential smoothing: the state space approach, Springer.
https://robjhyndman.com/expsmooth/
plot(unemp.cci[, 1:2], main = "Unemployment and the CCI", xlab = "Year")plot(unemp.cci[, 1:2], main = "Unemployment and the CCI", xlab = "Year")
Quarterly US GDP. 1947:1 - 2006.1.
usgdpusgdp
time series
Hyndman, R.J., Koehler, A.B., Ord, J.K., and Snyder, R.D., (2008) Forecasting with exponential smoothing: the state space approach, Springer
https://robjhyndman.com/expsmooth/
plot(usgdp, main = "Quarterly US GDP", xlab = "Year", ylab = "US Dollars")plot(usgdp, main = "Quarterly US GDP", xlab = "Year", ylab = "US Dollars")
Annual US net electricity generation (billion kwh) for 1949-2003
usnetelecusnetelec
time series
Hyndman, R.J., Koehler, A.B., Ord, J.K., and Snyder, R.D., (2008) Forecasting with exponential smoothing: the state space approach, Springer.
https://robjhyndman.com/expsmooth/
plot(usnetelec, main = "Annual US net electricity generation", ylab = "billion kwh", xlab = "Year")plot(usnetelec, main = "Annual US net electricity generation", ylab = "billion kwh", xlab = "Year")
Hourly utility demand, mid western USA from 1 Jan 2003
utilityutility
time series
Hyndman, R.J., Koehler, A.B., Ord, J.K., and Snyder, R.D., (2008) Forecasting with exponential smoothing: the state space approach, Springer.
https://robjhyndman.com/expsmooth/
plot(utility, main = "Hourly utility demand", ylab = "MW", xlab = "Day")plot(utility, main = "Hourly utility demand", ylab = "MW", xlab = "Day")
Hourly vehicle counts on Monash Freeway, outside Melbourne in Victoria, Australia, beginning August 1995.
vehiclesvehicles
time series
Hyndman, R.J., Koehler, A.B., Ord, J.K., and Snyder, R.D., (2008) Forecasting with exponential smoothing: the state space approach, Springer.
https://robjhyndman.com/expsmooth/
plot(vehicles, main = "Hourly vehicle count", xlab = "Day", ylab = "Number of vehicles")plot(vehicles, main = "Hourly vehicle count", xlab = "Day", ylab = "Number of vehicles")
Monthly Australian short-term overseas vistors. May 1985-April 2005
visitorsvisitors
time series
Hyndman, R.J., Koehler, A.B., Ord, J.K., and Snyder, R.D., (2008) Forecasting with exponential smoothing: the state space approach, Springer.
https://robjhyndman.com/expsmooth/
plot(visitors, main = "Overseas visitors to Australia", ylab = "Thousands of people", xlab = "Year")plot(visitors, main = "Overseas visitors to Australia", ylab = "Thousands of people", xlab = "Year")
Monthly foreign exchange rates: US dollar and UK pound against the Australia
dollar. audusd contains USD/AUD and audukp contains UKP/AUD.
xratesxrates
multiple time series
Hyndman, R.J., Koehler, A.B., Ord, J.K., and Snyder, R.D., (2008) Forecasting with exponential smoothing: the state space approach, Springer.
https://robjhyndman.com/expsmooth/
plot(xrates, main = "Foreign exchange rates", xlab = "Year")plot(xrates, main = "Foreign exchange rates", xlab = "Year")